@@ -5,23 +5,36 @@
 
 # Copyright (C) PyZMQ Developers
 # Distributed under the terms of the Modified BSD License.
+from typing import Any, Optional
 
 from tornado import ioloop
+
+import zmq
 from zmq.eventloop import zmqstream
+
 from .base import Authenticator
 
 
 class IOLoopAuthenticator(Authenticator):
     """ZAP authentication for use in the tornado IOLoop"""
 
-    def __init__(self, context=None, encoding='utf-8', log=None, io_loop=None):
-        super(IOLoopAuthenticator, self).__init__(context, encoding, log)
-        self.zap_stream = None
-        self.io_loop = io_loop or ioloop.IOLoop.instance()
+    zap_stream: zmqstream.ZMQStream
+    io_loop: ioloop.IOLoop
 
-    def start(self):
+    def __init__(
+        self,
+        context: Optional["zmq.Context"] = None,
+        encoding: str = 'utf-8',
+        log: Any = None,
+        io_loop: Optional[ioloop.IOLoop] = None,
+    ):
+        super().__init__(context, encoding, log)
+        self.zap_stream = None  # type: ignore
+        self.io_loop = io_loop or ioloop.IOLoop.current()
+
+    def start(self) -> None:
         """Start ZAP authentication"""
-        super(IOLoopAuthenticator, self).start()
+        super().start()
         self.zap_stream = zmqstream.ZMQStream(self.zap_socket, self.io_loop)
         self.zap_stream.on_recv(self.handle_zap_message)
 
@@ -30,6 +43,7 @@ class IOLoopAuthenticator(Authenticator):
         if self.zap_stream:
             self.zap_stream.close()
             self.zap_stream = None
-        super(IOLoopAuthenticator, self).stop()
+        super().stop()
+
 
 __all__ = ['IOLoopAuthenticator']
